===============================
**moca** --- Monte Carlo Module
===============================

This module includes classes and functions that allow to run MCMC sampling simulations
using a cluster expansion Hamiltonian with/or using optional pair potentials.

.. toctree::
   :maxdepth: 2

   ensembles
   processors
   sampler
   samplercontainer
   sublattice
